==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/BivariateRepresentations-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::RenderingOpenGL2")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_library_name" "vtkBivariateRepresentations")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateNoiseMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateNoiseRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateTextureRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLBivariateNoiseMapperDelegator.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateRepresentationsModule.h")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/BivariateRepresentations/vtk/hierarchy/BivariateRepresentations/vtkBivariateRepresentations-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.3-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/BivariateRepresentations-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;VTK::RenderingOpenGL2")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_library_name" "vtkBivariateRepresentations")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateNoiseMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateNoiseRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkBivariateTextureRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkOpenGLBivariateNoiseMapperDelegator.h")
set_property(TARGET "BivariateRepresentations::vtkBivariateRepresentations" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/BivariateRepresentations/vtk/hierarchy/BivariateRepresentations/vtkBivariateRepresentations-hierarchy.txt")
unset(_vtk_module_import_prefix)
